package com.ruoyi.szxc.service;

import com.ruoyi.szxc.domain.SzxcVoteResult;
import com.ruoyi.szxc.domain.YsResult;

import java.util.List;

/**
 * 议事投票情况Service接口
 * 
 * @author hs
 * @date 2024-03-20
 */
public interface ISzxcVoteResultService 
{
    /**
     * 查询议事投票情况
     * 
     * @param id 议事投票情况主键
     * @return 议事投票情况
     */
    public SzxcVoteResult selectSzxcVoteResultById(Long id);

    /**
     * 查询议事投票情况列表
     * 
     * @param szxcVoteResult 议事投票情况
     * @return 议事投票情况集合
     */
    public List<SzxcVoteResult> selectSzxcVoteResultList(SzxcVoteResult szxcVoteResult);

    /**
     * 新增议事投票情况
     * 
     * @param szxcVoteResult 议事投票情况
     * @return 结果
     */
    public int insertSzxcVoteResult(SzxcVoteResult szxcVoteResult);

    /**
     * 修改议事投票情况
     * 
     * @param szxcVoteResult 议事投票情况
     * @return 结果
     */
    public int updateSzxcVoteResult(SzxcVoteResult szxcVoteResult);

    /**
     * 批量删除议事投票情况
     * 
     * @param ids 需要删除的议事投票情况主键集合
     * @return 结果
     */
    public int deleteSzxcVoteResultByIds(Long[] ids);

    /**
     * 删除议事投票情况信息
     * 
     * @param id 议事投票情况主键
     * @return 结果
     */
    public int deleteSzxcVoteResultById(Long id);

    YsResult selectSzxcVoteResultByDiscussId(Long ysId);
}
